Volatile

Trait Volatile 

pub trait Volatile
where Self: Copy + PartialEq,
{ const ZEROED: Self; }
A trait restricting what kind of types can be put in the DiskVec

Apart from being Copy, the structure also assumes that a zero-valued instance of this type represents an empty slot in the memory mapped regions.

Required Associated Constants

const ZEROED: Self

A representation of this type used as a placeholder. Has to be represented by zeroes only.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors