pub trait Volatile{
const ZEROED: Self;
}Expand description
A trait restricting what kind of types can be put in the DiskVec
Apart from being Copy, the structure also assumes that a zero-valued
instance of this type represents an empty slot in the memory mapped regions.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.