Trait diskvec::Volatile [] [src]

pub trait Volatile where
    Self: Copy + PartialEq
{ const ZEROED: Self; }

A trait restricting what kind of types can be put in the DiskVec

Apart from being Copy, the structure also assumes that a zero-valued instance of this type represents an empty slot in the memory mapped regions.

Associated Constants

A representation of this type used as a placeholder. Has to be represented by zeroes only.

Implementors